@@ -348,7 +348,7 @@ class Suite:
         ipython = get_ipython()
         name_cell = ipython.compile.cache(code_source)
         code = compile(code_source, name_cell, "exec")
-        exec(code, ipython.user_global_ns, ipython.user_ns)
+        exec(code, ipython.user_global_ns, locals())
 
     def _test_cell(self, line: str, cell: Optional[str]) -> None:
         """
